@@ -5,7 +5,7 @@
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
 ;; URL: https://github.com/protesilaos/pulsar
-;; Version: 1.2.0
+;; Version: 1.3.1
 ;; Package-Requires: ((emacs "28.1"))
 ;; Keywords: convenience, pulse, highlight
 
@@ -66,7 +66,8 @@ pulse.  Only applies when `pulsar-pulse' is non-nil."
   :group 'pulsar)
 
 (defcustom pulsar-pulse-functions
-  '(backward-page
+  '(ace-window
+    backward-page
     bookmark-jump
     delete-other-windows
     delete-window
@@ -161,8 +162,7 @@ This only takes effect when `pulsar-mode' (buffer-local) or
     yank-rectangle)
   "Functions that highlight the affected region after invocation.
 When the value is nil, no pulsing is in effect.  Otherwise, the value is
-a list of functions that operate on the region.  It can be, for example,
-`pulsar-pulse-region-common-functions'.
+a list of functions that operate on the region.
 
 This only takes effect when `pulsar-mode' (buffer-local) or
 `pulsar-global-mode' is enabled."
@@ -387,9 +387,7 @@ extended to the edge of the window."
 (defun pulsar--create-pulse (locus face)
   "Create a pulse spanning the LOCUS using FACE.
 LOCUS is a cons cell with two buffer positions."
-  (let ((pulse-delay pulsar-delay)
-        (pulse-iterations pulsar-iterations)
-        (overlay (make-overlay (car locus) (cdr locus))))
+  (let ((overlay (make-overlay (car locus) (cdr locus))))
     (overlay-put overlay 'pulse-delete t)
     (overlay-put overlay 'window (frame-selected-window))
     (pulse-momentary-highlight-overlay overlay face)))
@@ -404,7 +402,10 @@ LOCUS is a cons cell with two buffer positions."
   "Create a pulse highlight for the current line.
 Also see `pulsar-highlight-pulse'."
   (interactive)
-  (pulsar--create-pulse (pulsar--get-line-boundaries) pulsar-face))
+  (let ((pulse-delay pulsar-delay)
+        (pulse-flag t)
+        (pulse-iterations pulsar-iterations))
+    (pulsar--create-pulse (pulsar--get-line-boundaries) pulsar-face)))
 
 ;;;###autoload
 (defun pulsar-highlight-pulse (&optional locus)
@@ -418,7 +419,9 @@ Otherwise, LOCUS spans the current line.
 For highlights without a pulse, see `pulsar-highlight-temporarily' and
 `pulsar-highlight-permanently'."
   (interactive (list (pulsar--get-line-or-region-boundaries)))
-  (let ((pulse-flag t))
+  (let ((pulse-flag t)
+        (pulse-delay pulsar-delay)
+        (pulse-iterations pulsar-iterations))
     (pulsar--create-pulse locus pulsar-face)))
 
 (define-obsolete-function-alias
@@ -427,7 +430,7 @@ For highlights without a pulse, see `pulsar-highlight-temporarily' and
   "1.3.0")
 
 (define-obsolete-function-alias
-  'pulsar-highlight-temporarily-dwim
+  'pulsar-highlight-dwim
   'pulsar-highlight-temporarily
   "1.3.0")
 
@@ -440,7 +443,9 @@ the highlight temporary.
 
 For a permanent highlight, see `pulsar-highlight-permanently'."
   (interactive (list (pulsar--get-line-or-region-boundaries)))
-  (let ((pulse-flag nil))
+  (let ((pulse-flag nil)
+        (pulse-delay nil)
+        (pulse-iterations nil))
     (pulsar--create-pulse locus pulsar-highlight-face)))
 
 ;;;###autoload
